from distutils.core import setup

setup(
    name='OddEven-SP',
    version='1.1.0',
    packages=['OddEvenSP'],
    url='https://github.com/Aarav2709/OddEven-SP',
    license='Apache License v2',
    author='Aarav Gupta',
    author_email='tribejustice35@gmail.com',
    description='So, welcome to my first ever Python Project! That is a game based on Odd Even, but with a twist of Cricket!'
)
